@@ -28,6 +28,7 @@ import json
 import logging 
 import os
 import requests
+import socket
 import sys
 import time
 import traceback
@@ -721,6 +722,7 @@ class LocalLogCache:
         dd['dc_time_now'] = tn
         dd['dc_message'] = message
         dd['dc_sev'] = sev
+        dd['dc_host'] = socket.gethostname()
         self.logs.insert(0, dd)
         return
 
@@ -743,4 +745,4 @@ class LocalLogCache:
     def log_sql(self, table, stmt):
         # do something.
         return self._log('info', '%s: %s' % (table, stmt), { 'table': table, 'stmt': stmt })
-        
\ No newline at end of file
+        
